==> opendbl-r80-0.4.tar: opendbl-installer/install.sh <==
echo "*************************************************"
echo "Making sure cpdbl is not enabled."
echo "*************************************************"
echo ""
echo ""
/opt/CPshrd-R80/bin/cpdbl.sh etknown off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh tor off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh bruteforce off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh talos off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh blocklistde off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh malware off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh sslblock off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh zeus off > /dev/null 2>&1

echo "*************************************************"
echo "cleaning up old files"
echo "*************************************************"

rm /opt/CPshrd-R80/bin/cpdbl.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/conf/cpdbl.crt > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-bruteforce.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-dshield.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-etknown.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-include.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-malware.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-sslblock.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-talos.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-tor.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-zeus.sh > /dev/null 2>&1
echo "*************************************************"
echo "all done..."
echo "*************************************************"
echo ""
echo "*************************************************"
echo "installing opendbl"
echo "*************************************************"

cp opendbl.crt $CPDIR/conf/opendbl.crt > /dev/null 2>&1
cp ip-opendbl-*.sh /opt/CPshrd-R80/bin/ > /dev/null 2>&1
chmod +x /opt/CPshrd-R80/bin/ip-opendbl-*.sh > /dev/null 2>&1
cp opendbl.sh /opt/CPshrd-R80/bin/ > /dev/null 2>&1
chmod +x /opt/CPshrd-R80/bin/opendbl.sh > /dev/null 2>&1
echo ""
echo ""
echo ""
echo "*************************************************"
echo "Installation done"
echo "*************************************************"
echo ""
/opt/CPshrd-R80/bin/opendbl.sh
echo ""
echo ""
echo "*************************************************"
echo "If you upgraded from cpdbl remember to update the object names used in your security policy from CPDBL_listname to openDBL_listname"
echo "*************************************************"
echo ""
echo ""

==> opendbl-r80-0.5.tar: opendbl-installer/install.sh <==
echo "*************************************************"
echo "Making sure cpdbl is not enabled."
echo "*************************************************"
echo ""
echo ""
/opt/CPshrd-R80/bin/cpdbl.sh etknown off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh tor off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh bruteforce off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh talos off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh blocklistde off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh malware off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh sslblock off > /dev/null 2>&1
/opt/CPshrd-R80/bin/cpdbl.sh zeus off > /dev/null 2>&1

echo "*************************************************"
echo "cleaning up old files"
echo "*************************************************"

rm /opt/CPshrd-R80/bin/cpdbl.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/conf/cpdbl.crt > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-bruteforce.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-dshield.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-etknown.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-include.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-malware.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-sslblock.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-talos.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-tor.sh > /dev/null 2>&1
rm /opt/CPshrd-R80/bin/ip-cpdbl-zeus.sh > /dev/null 2>&1
echo "*************************************************"
echo "all done..."
echo "*************************************************"
echo ""
echo "*************************************************"
echo "installing opendbl"
echo "*************************************************"

cp opendbl.crt $CPDIR/conf/opendbl.crt > /dev/null 2>&1
cp ip-opendbl-*.sh $CPDIR/bin/ > /dev/null 2>&1
chmod +x $CPDIR/bin/ip-opendbl-*.sh > /dev/null 2>&1
cp opendbl.sh $CPDIR/bin/ > /dev/null 2>&1
chmod +x $CPDIR/bin/opendbl.sh > /dev/null 2>&1
echo ""
echo ""
echo ""
echo "*************************************************"
echo "Installation done"
echo "*************************************************"
echo ""
$CPDIR_PATH/bin/opendbl.sh
echo ""
echo ""
echo "*************************************************"
echo "If you upgraded from cpdbl remember to update the object names used in your security policy from CPDBL_listname to openDBL_listname"
echo "*************************************************"
echo ""
echo ""
